# SourcePath: openssl/20230313dev
%define libmaj 3
%define libmin 0
%define librel 7
Release: 12010001

%define openssldir %{sony_target_dev_lib_dir}/ssl
%define sony_target_arch debian-%{sony_target_cpu_longname}
%define shlib_maj 3
%define shlib_min 0
# sony_target_cpu_longname is "powerpc" or "arm"
%define sony_target_arch debian-armel
Summary: Secure Sockets Layer and cryptography libraries and tools
Name: sony-target-dev-openssl-with-ec
%define pkgname %{sony_tool_triplet}-%{sony_target_dialect}-dev-openssl-with-ec
Version: %{libmaj}.%{libmin}.%{librel}
Source0: openssl-%{version}.tar.gz
Source1: openssl_3.0.7-1ubuntu1.debian.tar.xz
Patch0: remove_fzero-call-used-regs.patch
License: OpenSSL license / SSLeay license
Distribution: %{sony_distribution}
Vendor: %{sony_vendor}
Packager: %{sony_packager}
Group: %{sony_group}
Provides: SSL
URL: http://www.openssl.org/
BuildRoot:   /var/tmp/%{name}-%{version}-root
Prefix: %{sony_target_dir}
%define _docdir         %{sony_target_dir}%{sony_target_dev_doc_dir}


%description
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols as well as a full-strength general purpose cryptography library.
The project is managed by a worldwide community of volunteers that use the
Internet to communicate, plan, and develop the OpenSSL tookit and its related
documentation.

%package -n %{pkgname}
Summary: Secure Sockets Layer and cryptography static libraries and headers
Group: %{sony_group}
AutoReqProv: no

%description -n %{pkgname}
The OpenSSL Project is a collaborative effort to develop a robust,
commercial-grade, fully featured, and Open Source toolkit implementing the
Secure Sockets Layer (SSL v2/v3) and Transport Layer Security (TLS v1)
protocols as well as a full-strength general purpose cryptography library.
The project is managed by a worldwide community of volunteers that use the
Internet to communicate, plan, and develop the OpenSSL tookit and its related
documentation.


%prep
# %target_check
%setup -q -n openssl-%{version} -q -a 1

cd ${RPM_BUILD_DIR}/openssl-%{version}
cat debian/patches/*.patch > debian.patch

patch -p1 < debian/patches/debian-targets.patch
patch -p1 < debian/patches/man-section.patch
patch -p1 < debian/patches/no-symbolic.patch
patch -p1 < debian/patches/pic.patch
patch -p1 < debian/patches/c_rehash-compat.patch
patch -p1 < debian/patches/Configure-allow-to-enable-ktls-if-target-does-not-start-w.patch
patch -p1 < debian/patches/conf-Serialize-allocation-free-of-ssl_names.patch
patch -p1 < debian/patches/Fix-tests-for-new-default-security-level.patch
patch -p1 < debian/patches/x509-fix-double-locking-problem.patch
patch -p1 < debian/patches/tests-use-seclevel-1.patch
patch -p1 < debian/patches/tls1.2-min-seclevel2.patch
patch -p1 < debian/patches/skip_tls1.1_seclevel3_tests.patch
%patch0 -p1

%build
%sony_target_dev_setup
# acck, gaaagh, choke  horrible hack
perl -spi -e "s/\"gcc:/\"%{sony_target_toolprefix}gcc %{sony_target_machine_option}:/" Configure
perl -spi -e "s/which\(\"ranlib\"\)/which\(\"%{sony_target_toolprefix}ranlib\"\)/" Configure


# Define the global setups..
%define CONFIG_FLAGS --prefix=%{sony_target_dev_prefix} no-idea no-mdc2 no-rc5 --openssldir=%{openssldir}

# First we build static libs...
./Configure no-shared %{CONFIG_FLAGS} %{sony_target_arch}
make depend
make -f Makefile DIRS="crypto ssl" all
mv libcrypto.a libcrypto.static
mv libssl.a libssl.static
make -f Makefile DIRS="crypto ssl" clean

# Next we build shared libs...
./Configure shared %{CONFIG_FLAGS} %{sony_target_arch}
for f in `find . -name 'Makefile' -print `;
do
sed 's/arm-sony-linux-gnueabi-ar/ar/g' $f > $f.tmp;
mv $f.tmp $f;
done
ln -sf apps/openssl.pod crypto/crypto.pod ssl/ssl.pod doc/

# Multi-dialect support modification in Makefile
mv Makefile Makefile.orig
sed -e "s/FIPSLD_CC=\$(CC)/FIPSLD_CC='\$(CC)'/g" -e 's/CC=$${CC}/CC="$${CC}"/g' Makefile.orig > Makefile

make -f Makefile all

%install
rm -rf %{buildroot}
%sony_target_dev_setup

make -f Makefile  install DESTDIR=%{buildroot}%{sony_target_dir}
install -m 0644 libcrypto.static \
	%{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/libcrypto.a
install -m 0644 libssl.static \
	%{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/libssl.a

mkdir -p %{buildroot}%{sony_target_dir}%{sony_target_dev_sysconf_dir}/ssl/
mv %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/{certs,openssl.cnf,private} \
	%{buildroot}%{sony_target_dir}%{sony_target_dev_sysconf_dir}/ssl/
ln -s ../../../etc/ssl/{certs,openssl.cnf,private} \
	%{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/

cp -af lib*.so* \
	%{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}

# Fix up libs permissions.. just in case...
chmod 0644 %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/lib*

# Create the major version links
(
        cd %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}
        ln -s libcrypto.so.%{libmaj} libcrypto.so.%{shlib_maj}.%{shlib_min} 
        ln -s libssl.so.%{libmaj} libssl.so.%{shlib_maj}.%{shlib_min}
)

# clean out unpackaged files

rm -rf  %{buildroot}%{sony_target_dir}%{sony_target_dev_data_dir}/man
rm -rf  %{buildroot}%{sony_target_dir}%{sony_target_dev_data_dir}/doc/openssl/html
rm -rf  %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/man
rm -rf  %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/fips_premain.*

# 6.x
mkdir -p ${RPM_BUILD_ROOT}%{sony_target_dir}%{sony_target_devtool_lib_dir}
mv ${RPM_BUILD_ROOT}%{sony_target_dir}%{sony_target_dev_lib_dir}/pkgconfig \
        ${RPM_BUILD_ROOT}%{sony_target_dir}%{sony_target_devtool_lib_dir}

    mkdir -p  %{buildroot}%{sony_target_dir}%{sony_target_devtool_lib_dir}
    mv %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/*.a \
       %{buildroot}%{sony_target_dir}%{sony_target_devtool_lib_dir}

    for l in `ls %{buildroot}%{sony_target_dir}%{sony_target_devtool_lib_dir}`
    do
	if [ "$l" != "pkgconfig" -a "$l" != "optinfo" ]; then
	   ln -s ../..%{sony_target_devtool_lib_dir}/$l \
	       %{buildroot}%{sony_target_dir}%{sony_target_dev_lib_dir}/$l
	fi
    done

mkdir -p  %{buildroot}%{sony_target_dir}%{sony_target_dev_include_dir}
mv  %{buildroot}%{sony_target_dir}%{sony_target_dev_dir}/usr/include/* \
        %{buildroot}%{sony_target_dir}%{sony_target_dev_include_dir}

%clean
rm -rf $RPM_BUILD_ROOT


%files -n %{pkgname}
%defattr(0644,root,root,0755)
### %doc CHANGES CHANGES.SSLeay LICENSE NEWS README

%attr(0755,root,root)%{sony_target_dir}%{sony_target_dev_bin_dir}/c_rehash
%attr(0755,root,root)%{sony_target_dir}%{sony_target_dev_bin_dir}/openssl

%{sony_target_dir}%{sony_target_dev_lib_dir}/libcrypto.so.%{shlib_maj}.%{shlib_min}
%{sony_target_dir}%{sony_target_dev_lib_dir}/libssl.so.%{shlib_maj}.%{shlib_min}

%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/certs
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/ct_log_list.cnf
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/ct_log_list.cnf.dist
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/openssl.cnf.dist
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libchil.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libcswift.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libgmp.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libnuron.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libsureware.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libubsec.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libcapi.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libpadlock.so
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/engines/libgost.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/engines-3/afalg.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/engines-3/capi.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/engines-3/padlock.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/CA.pl
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/CA.sh
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/c_hash
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/c_info
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/c_issuer
#%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/c_name
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/tsget
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/misc/tsget.pl
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/openssl.cnf
%{sony_target_dir}%{sony_target_dev_lib_dir}/ssl/private

%{sony_target_dir}%{sony_target_dev_sysconf_dir}/ssl/certs
%{sony_target_dir}%{sony_target_dev_sysconf_dir}/ssl/openssl.cnf
%{sony_target_dir}%{sony_target_dev_sysconf_dir}/ssl/private

### %doc %attr(0644,root,root) %{sony_cross_target_dir}%{sony_target_dev_man_dir}/man[157]/*


%{sony_target_dir}%{sony_target_devtool_lib_dir}/pkgconfig/libcrypto.pc
%{sony_target_dir}%{sony_target_devtool_lib_dir}/pkgconfig/libssl.pc
%{sony_target_dir}%{sony_target_devtool_lib_dir}/pkgconfig/openssl.pc

%{sony_target_dir}%{sony_target_dev_lib_dir}/libcrypto.a
%{sony_target_dir}%{sony_target_devtool_lib_dir}/libcrypto.a
%{sony_target_dir}%{sony_target_dev_lib_dir}/libcrypto.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/libcrypto.so.3
%{sony_target_dir}%{sony_target_dev_lib_dir}/libssl.a
%{sony_target_dir}%{sony_target_devtool_lib_dir}/libssl.a
%{sony_target_dir}%{sony_target_dev_lib_dir}/libssl.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/libssl.so.3
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/aes.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/asn1.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/asn1_mac.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/asn1t.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/bio.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/blowfish.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/bn.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/buffer.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cast.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/comp.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/conf.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/conf_api.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/crypto.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/des.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/des_old.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dh.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dsa.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dso.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dtls1.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/e_os2.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ebcdic.h
# commeted for with-ec option in CONFIG_FLAGS
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ec.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ecdh.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ecdsa.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/engine.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/err.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/evp.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/hmac.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/krb5_asn.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/kssl.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/lhash.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/md4.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/md5.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/obj_mac.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/objects.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ocsp.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/opensslconf.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/opensslv.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ossl_typ.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pem.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pem2.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pkcs12.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pkcs7.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cms.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/modes.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ts.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/whrlpool.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pq_compat.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pqueue.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rand.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rc2.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rc4.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ripemd.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rsa.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/safestack.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/sha.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ssl.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ssl2.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ssl23.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ssl3.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/stack.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/store.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/symhacks.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/tls1.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/tmdiff.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/txt_db.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ui.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ui_compat.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/x509.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/x509_vfy.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/x509v3.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cmac.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/srp.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/srtp.h
#%{sony_cross_target_dir}%{sony_target_dev_include_dir}/openssl/fips.h
#%{sony_cross_target_dir}%{sony_target_dev_include_dir}/openssl/fips_rand.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/asn1err.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/async.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/asyncerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/bioerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/bnerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/buffererr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/camellia.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cmserr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/comperr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/conferr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cryptoerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ct.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/cterr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dherr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/dsaerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ec.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ecdh.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ecdsa.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ecerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/engineerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/evperr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/idea.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/kdf.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/kdferr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/md2.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/mdc2.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/objectserr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/ocsperr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pemerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pkcs12err.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/pkcs7err.h
#%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rand_drbg.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/randerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rc5.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/rsaerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/seed.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/sslerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/storeerr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/tserr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/uierr.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/x509err.h
%{sony_target_dir}%{sony_target_dev_include_dir}/openssl/x509v3err.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/cmp.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/cmp_util.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/cmperr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/configuration.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/conftypes.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/core.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/core_dispatch.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/core_names.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/core_object.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/crmf.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/crmferr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/cryptoerr_legacy.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/decoder.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/decodererr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/encoder.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/encodererr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/ess.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/esserr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/fips_names.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/fipskey.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/http.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/httperr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/macros.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/param_build.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/params.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/prov_ssl.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/proverr.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/provider.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/self_test.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/sslerr_legacy.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/trace.h
%{sony_target_dir}%{sony_target_devtool_include_dir}/openssl/types.h
%{sony_target_dir}%{sony_target_dev_lib_dir}/engines-3/loader_attic.so
%{sony_target_dir}%{sony_target_dev_lib_dir}/ossl-modules/legacy.so


### %doc %attr(0644,root,root) %{sony_cross_target_dir}%{sony_target_dev_man_dir}/man[3]/*
### %doc LICENSE


%changelog
* Tue Mar 14 2023 Sony Group Corporation
- Version update to 3.0.7

* Mon May 10 2021 Sony Corporation
- Initial build for CE Linux 12.1.0.X

* Fri Dec 11 2020 Sony Corporation
- Added CVE-fix for CVE-2019-1547, CVE-2019-1549, CVE-2019-1551
  CVE-2019-1563 and CVE-2020-1971

* Mon Jul 29 2019 Sony Corporation
- Updated to openssl-1.1.1a

* Tue Jan 17 2017 Sony Corporation
- Updated to openssl-1.0.2k

* Thu Mar 03 2016 Sony Corporation
- Updated to openssl-1.0.2g

* Mon Feb 08 2016 Sony Corporation
- Updated to openssl-1.0.2f , used ubuntu debian patch

* Tue Apr 02 2013 Sony Corporation 
- update to openssl-1.0.1e 

* Fri Jan 20 2012 Sony Corporation
- update to openssl-0.9.8t

* Mon Jan 02 2012 Sony Corporation
- added CVE-2011-3210 security patch

* Mon Sep 26 2011 Sony Corporation
- added CVE-2011-1945 security patch

* Mon Feb 21 2011 Sony Corporation
- update to openssl-0.9.8r

* Mon Dec 27 2010 Sony Corporation
- added CVE-2010-4180 security patch

* Thu Dec 02 2010 Sony Corporation
- add CVE-2010-3864 security fix patch

* Mon Nov 22 2010 Sony Corporation
- Initial build for openssl-with-ec package.
